Visible-members query for autocomplete / LSP completions.
Given a Union type, returns all methods, properties, and constants that
are visible on that type, walking the full inheritance hierarchy.
Structs
- Member
Info - A single member visible on a type.
Enums
- Member
Kind - The kind of class member.