Structs
- Assertion
- Class
Storage - Constant
Storage - Enum
Case Storage - Enum
Storage - FnParam
- Function
Storage - Interface
Storage - Location
- Declaration location.
- Method
Storage - Property
Storage - Stub
Slice - A snapshot of all PHP definitions contributed by a single stub file set.
- Template
Param - Trait
Storage
Enums
Functions
- deduplicate_
params_ in_ slice - Deduplicate parameter lists across all methods and functions in a StubSlice.
Many PHP framework methods share identical parameter lists (e.g., thousands
of
(string $arg, array $opts)signatures). This function groups identical param lists globally (across all slices processed so far) and replaces them with Arc<FnParam> pointers to shared allocations. - wrap_
param_ type - Helper to wrap Option
in interned Arc . - wrap_
return_ type - Helper to wrap return type Option
in interned Arc .